/******************************************************************************
 * bullet object headers
 *
 * written by Doug Lanford, opus@opusgames.com
 * for more info, go to www.opusgames.com
 *
 * This file is provided as freeware
 *****************************************************************************/


#include "bullet.h"
#include "game.h"
#include "sprite.h"
#include "math.h"
#include "world.h"
#include "collide.h"
#include "explosion.h"


s24f8_vect2D bulletSize = {int_to_s24f8(4), int_to_s24f8(4)};

/********************************************************************
 * launch a bullet
 *
 * IN:		world positon of the bullet
 * 			speed it travels at
 *
 * RETURNS:	ptr to the bullet object
 *******************************************************************/
BulletStruct *Bullet_New (s24f8_vect2D *pPos, s24f8_vect2D *pSpeed)
{
u32 objID;
BulletStruct *pBullet;

	// grab a new object
	objID = Object_New(OBJECT_BULLET);
	if (objID == OBJECT_ID_NULL)
	{	// error... no unused objects left
		return(NULL);
	}

	// get the pointer to it
	pBullet = (BulletStruct *)Object_getPtrS(objID);

	pBullet->pos.x = pPos->x + SHOT_OFFSET_X;
	pBullet->pos.y = pPos->y + SHOT_OFFSET_Y;

	pBullet->curFrame = 0;
	pBullet->frameTimer = BULLET_ANIM_TIME;

	pBullet->speed.x = pSpeed->x;
	pBullet->speed.y = pSpeed->y;

	pBullet->lifeTimer = BULLET_LIFETIME;

	return(pBullet);
}


/**********************************************************************
 * update a bullet object
 *********************************************************************/
u32 Bullet_Update (ObjectStruct *pObj)
{
BulletStruct *pBullet = (BulletStruct *)pObj;

	pBullet->lifeTimer -= frameTimeF;
	if (pBullet->lifeTimer < 0)
	{	// bullet timed out... kill it
		return(1);
	}

	if (Collide_PointToShip(&pBullet->pos))
	{	// bullet collided with an ai ship... set off an explosion and kill the bullet
		Explosion_New(&pBullet->pos);
		return(1);
	}

	// move the bullet
	pBullet->pos.x += s24f8_mul(pBullet->speed.x, frameTimeF);
	pBullet->pos.y += s24f8_mul(pBullet->speed.y, frameTimeF);

	// count down to next frame
	pBullet->frameTimer -= frameTimeF;
	while (pBullet->frameTimer < 0)
	{	// update to next frame
		pBullet->frameTimer += BULLET_ANIM_TIME;

		pBullet->curFrame++;
		if (pBullet->curFrame >= 4)
		{
			pBullet->curFrame = 0;
		}
	}

	Sprite_OnScreenUpdate(&pBullet->pos, &bulletSize, &gWorldPos,
						  SPRITE_COLOR_MODE_256, SPRITE_SIZE_8, (BULLETS_TILENUM + pBullet->curFrame)<<1);

	return(0);
}

