/******************************************************************************
 * bullet object headers
 *
 * written by Doug Lanford, opus@opusgames.com
 * for more info, go to www.opusgames.com
 *
 * This file is provided as freeware
 *****************************************************************************/

#ifndef _BULLET_H
#define	_BULLET_H

#include "types.h"
#include "math.h"
#include "object.h"

#define SHOT_TIME	float_to_s24f8(7.5f)

#define	BULLET_ANIM_TIME	float_to_s24f8(6)
#define	BULLET_LIFETIME		float_to_s24f8(60 * 1.5f)

#define	SHOT_OFFSET_X		int_to_s24f8(0)
#define	SHOT_OFFSET_Y		int_to_s24f8(0)

typedef struct BulletStruct
{
	OBJECT_HEADER

	s24f8_vect2D	pos;		// world position of the bullet
	s24f8_vect2D	speed;		// speed vector of the bullet

	u16				curFrame;	// animation frame the bullet is on
	s24f8			frameTimer;	// time till next frame change

	s24f8			lifeTimer;	// time left until bullet goes away

} BulletStruct;


/********************************************************************
 * launch a bullet
 *
 * IN:		world positon of the bullet
 * 			speed it travels at
 *
 * RETURNS:	ptr to the bullet object
 *******************************************************************/
extern BulletStruct *Bullet_New (s24f8_vect2D *pPos, s24f8_vect2D *pSpeed);


/**********************************************************************
 * update a bullet object
 *********************************************************************/
extern u32 Bullet_Update (ObjectStruct *pObj);


#endif

