/*******************************************************************
 * code for explosion game objects
 *
 * written by Doug Lanford, opus@opusgames.com
 * for more info, go to www.opusgames.com
 *
 * This file is provided as freeware
 ******************************************************************/

#include "explosion.h"
#include "game.h"
#include "sprite.h"
#include "world.h"




s24f8_vect2D explodeSize = {int_to_s24f8(8), int_to_s24f8(8)};

/********************************************************************
 * launch an explosion
 *
 * IN:		world position of the explosion
 *
 * RETURNS:	ptr to the explosion object
 *******************************************************************/
ExplosionStruct *Explosion_New (s24f8_vect2D *pPos)
{
u32 objID;
ExplosionStruct *pExplosion;

	// grab a new object
	objID = Object_New(OBJECT_EXPLOSION);
	if (objID == OBJECT_ID_NULL)
	{	// error... no unused objects left
		return(NULL);
	}

	// get the pointer to it
	pExplosion = (ExplosionStruct *)Object_getPtrS(objID);

	pExplosion->pos = *pPos;

	pExplosion->curFrame = 0;
	pExplosion->frameTimer = EXPLOSION_ANIM_TIME;

	pExplosion->attrib0 = SPRITE_COLOR_MODE_256;
	pExplosion->attrib1 = SPRITE_SIZE_16 + (Random_Get32() & (SPRITE_HFLIP | SPRITE_VFLIP));

	return(pExplosion);
}




/**********************************************************************
 * update an explosion object
 *********************************************************************/
u32 Explosion_Update (ObjectStruct *pObj)
{
ExplosionStruct *pExplosion = (ExplosionStruct *)pObj;

	// count down to next frame
	pExplosion->frameTimer -= frameTimeF;
	while (pExplosion->frameTimer < 0)
	{	// update to next frame
		pExplosion->frameTimer += EXPLOSION_ANIM_TIME;

		pExplosion->curFrame++;
		if (pExplosion->curFrame >= 15)
		{	// explosion is finished... remove it
			return(1);
		}
	}

	Sprite_OnScreenUpdate(&pExplosion->pos, &explodeSize, &gWorldPos,
						  SPRITE_COLOR_MODE_256, SPRITE_SIZE_16, (EXPLO_TILENUM + (pExplosion->curFrame<<2))<<1);

	return(0);
}



