/*************************************************************************
 * GBA hardware display mode information
 *
 * written by Doug Lanford, opus@opusgames.com
 * for more info, go to www.opusgames.com
 *
 * This file is provided as freeware
 ************************************************************************/

#ifndef	_GBA_DISP_H
#define	_GBA_DISP_H


#include "types.h"



// display mode register
#define	pREG_DISPLAY_MODE			(u32 *)0x4000000
#define	REG_DISPLAY_MODE			*pREG_DISPLAY_MODE

// display mode types
#define	DISP_MODE_MASK				0x0007		// mask for screen mode
#define	DISP_MODE_0					0x0001		// mode 0 - tile display, all 4 backgrounds, no rotation
#define	DISP_MODE_1					0x0001		// mode 1 - tile display, backgrounds 0,1,2, rotation on 2
#define	DISP_MODE_2					0x0002		// mode 2 - tile display, backgrounds 2,3, rotation on both
#define	DISP_MODE_3					0x0003		// mode 3 - pixel display
#define	DISP_MODE_4					0x0004		// mode 4 - paletted pixel display
#define	DISP_MODE_5					0x0005		// mode 5 - interleaved pixel display

//	various flags
#define	DISP_GB_FLAG				0x0008		// GB or GBA cartridge flag
#define	DISP_OAM_HBLANK				0x0020		// flag - update OAM during h-blank
#define	DISP_FORCE_BLANK			0x0080		// flag - force blank mode

// active buffer flag (modes 4 and 5 only)
#define	DISP_ACTIVE_BUFFER_FRONT	0x0000	// enable front buffer
#define	DISP_ACTIVE_BUFFER_BACK		0x0010	// enable back buffer

// Sprite mapping setting
#define	DISP_SPRITE_MAPPING_2D		0x0000		// 2D mapping (tile RAM is 2D array of tiles
#define	DISP_SPRITE_MAPPING_1D		0x0040		// 1D mapping (tile RAM is linear array of tiles)

// background and sprite settings
#define	DISP_MAPOBJ_MASK			0x1F00		// mask for background and obj display settings
#define	DISP_MAP_0					0x0100		// enable background 0
#define	DISP_MAP_1					0x0200		// enable background 1
#define	DISP_MAP_2					0x0400		// enable background 2
#define	DISP_MAP_3					0x0800		// enable background 3
#define	DISP_SPRITES				0x1000		// enable sprites

// window settings
#define	DISP_WINDOW_MASK			0xE000		// mask for window display settings
#define	DISP_WIN1					0x2000		// enable window 1
#define	DISP_WIN2					0x2000		// enable window 1
#define	DISP_WINOBJ					0x2000		// enable window sprites

// background sprite and background blending / transparency
#define pREG_BLEND_SETTINGS 		(u16 *)0x4000050
#define	REG_BLEND_SETTINGS			*pREG_BLEND_SETTINGS

#define	BLEND_FIRST_BG0				0x0001
#define	BLEND_FIRST_BG1				0x0002
#define	BLEND_FIRST_BG2				0x0004
#define	BLEND_FIRST_BG3				0x0008
#define	BLEND_FIRST_OBJ				0x0010
#define	BLEND_FIRST_BD				0x0020

#define	BLEND_SECOND_BG0			0x0100
#define	BLEND_SECOND_BG1			0x0200
#define	BLEND_SECOND_BG2			0x0400
#define	BLEND_SECOND_BG3			0x0800
#define	BLEND_SECOND_OBJ			0x1000
#define	BLEND_SECOND_BD				0x2000

#define	BLEND_ALPHA_MODE_MASK		0x00C0
#define	BLEND_ALPHA_NONE			0x0000
#define	BLEND_ALPHA_NORMAL			0x0040
#define	BLEND_ALPHA_FADEIN			0x0080
#define	BLEND_ALPHA_FADEOUT			0x00C0

#define pREG_BLEND_LEVELS			(u16 *)0x4000052
#define REG_BLEND_LEVELS			*pREG_BLEND_LEVELS

#define	REG_BLEND_FIRST_MASK		0x001F
#define	REG_BLEND_SECOND_MASK		0x1F00

#define	SetBlendLevel(level1, level2)	(REG_BLEND_LEVELS = ((level2<<8) | level1))

// top of VRAM
#define	VRAM_TOP					0x06000000			// beginning of video RAM

// scanline counter register (>160 means v-blank)
#define	REG_SCANLINE_COUNT			0x04000006


#endif

