/*****************************************************************
 * GBA hardware timers
 *
 * written by Doug Lanford, opus@opusgames.com
 * for more info, go to www.opusgames.com
 *
 * This file is provided as freeware
 ****************************************************************/

#ifndef	GBA_TIMER_H
#define	GBA_TIMER_H


// GBA timer registers
// 	  VALUE = the timer's current value
// 	  CONTROL = control settings (timer frequency, enable, etc)
#define	pREG_TIMER_0_VALUE		(u16 *)0x4000100
#define	REG_TIMER_0_VALUE		*pREG_TIMER_0_VALUE
#define	pREG_TIMER_0_CONTROL	(u16 *)0x4000102
#define	REG_TIMER_0_CONTROL		*pREG_TIMER_0_CONTROL

#define	pREG_TIMER_1_VALUE		(u16 *)0x4000104
#define	REG_TIMER_1_VALUE		*pREG_TIMER_1_VALUE
#define	pREG_TIMER_1_CONTROL	(u16 *)0x4000106
#define	REG_TIMER_1_CONTROL		*pREG_TIMER_1_CONTROL

#define	pREG_TIMER_2_VALUE		(u16 *)0x4000108
#define	REG_TIMER_2_VALUE		*pREG_TIMER_2_VALUE
#define	pREG_TIMER_2_CONTROL	(u16 *)0x400010A
#define	REG_TIMER_2_CONTROL		*pREG_TIMER_2_CONTROL

#define	pREG_TIMER_2_VALUE		(u16 *)0x400010C
#define	REG_TIMER_2_VALUE		*pREG_TIMER_2_VALUE
#define	pREG_TIMER_3_CONTROL	(u16 *)0x400010E
#define	REG_TIMER_3_CONTROL		*pREG_TIMER_3_CONTROL


// timer control register bit values
// NOTE: a timer set for the 256 frequency will run a full cycle (0..65536) in exactly one second!
#define	TIMER_FREQ_MASK			0x0003	// mask for timer frequency settings
#define	TIMER_FREQ_SYSTEMCLOCK	0x0000	// max frequency (CPU clock speed) - 16.78 MHz (~ 59.595 nanosec per tick)
#define	TIMER_FREQ_64			0x0001	// 1 tick = 64 clock cycles (~ 3.814 microsec per tick)
#define	TIMER_FREQ_256			0x0002	// 1 tick = 256 clock cycles (~15.256 microsec per tick)
#define	TIMER_FREQ_1024			0x0003	// 1 tick = 1024 clock cycles (~61.025 microsec per tick)

#define	TIMER_OVERFLOW			0x0004	// if set, then if the timer below this one overflows, this timer increments
#define	TIMER_INTERRUPT_ENABLE	0x0040	// if set, the timer will generate an interrupt when it overflows
#define	TIMER_ENABLE			0x0080	// if set, the timer is active


#endif

