/********************************************************************
 * text and number displaying routines
 *
 * written by Doug Lanford, opus@opusgames.com
 * for more info, go to www.opusgames.com
 *
 * This file is provided as freeware
 ********************************************************************/

#include "text.h"
#include "math.h"
#include "sprite.h"
#include "game.h"

/********************************************************************************
 * display a number at a screen position on the screen
 *
 * IN:		screenX, screenY = screen position (0,0 = top-left corner of screen)
 * 			num = value to display
 *******************************************************************************/
void Text_DrawNumber(u16 screenX, u16 screenY, u16 num)
{
u8 outNums[8];
u16 outCount = 0;
u16 tmp;
u16 flag = 0;

	if (num >= 10000)
	{
		tmp = s32_div(num, 10000);

		outNums[outCount++] = tmp;

		num -= 10000 * tmp;

		flag = 1;
	}

	if (num >= 1000)
	{
		tmp = s32_div(num, 1000);

		outNums[outCount++] = tmp;

		num -= 1000 * tmp;

		flag = 1;
	}
	else if (flag)
	{
		outNums[outCount++] = 0;
	}

	if (num >= 100)
	{
		tmp = s32_div(num, 100);

		outNums[outCount++] = tmp;

		num -= 100 * tmp;

		flag = 1;
	}
	else if (flag)
	{
		outNums[outCount++] = 0;
	}


	if (num >= 10)
	{
		tmp = s32_div(num, 10);

		outNums[outCount++] = tmp;

		num -= 10 * tmp;
	}
	else if (flag)
	{
		outNums[outCount++] = 0;
	}

	outNums[outCount++] = num;

	for (tmp=0; tmp<outCount; tmp++)
	{
		Sprite_LoadNextSlot(SPRITE_COLOR_MODE_256 + screenY, SPRITE_SIZE_8 + screenX, (NUMS_TILENUM + outNums[tmp])<<1);
		screenX += 8;
	}
}


/********************************************************************************
 * display text at a screen position on the screen
 *
 * IN:		screenX, screenY = screen position (0,0 = top-left corner of screen)
 * 			pText = text to print
 *******************************************************************************/
void Text_DrawString(u16 screenX, u16 screenY, u8 *pText)
{
s8 ch;
s16 tileNum;

	if (pText == NULL)
	{
		return;
	}

	while (*pText != 0)
	{
		ch = *pText++;
		tileNum = -1;

		if ((ch >= 'A') && (ch <= 'Z'))
		{	// upper case letter
			tileNum = (ch - 'A') + LETTERS_TILENUM;
		}
		else if ((ch >= 'a') && (ch <= 'z'))
		{	// lower-case letter
			tileNum = (ch - 'A') + LETTERS_TILENUM;
		}
		else if ((ch >= '0') && (ch <= '9'))
		{	// number
			tileNum = (ch - '0') + NUMS_TILENUM;
		}
		else if (ch == '-')
		{	// special character
			tileNum = LETTERS_TILENUM + 26;
		}
		else if (ch == ':')
		{	// special character
			tileNum = LETTERS_TILENUM + 27;
		}
		else if (ch == ' ')
		{
			screenX += 8;
		}

		if (tileNum >= 0)
		{
			Sprite_LoadNextSlot(SPRITE_COLOR_MODE_256 + screenY, SPRITE_SIZE_8 + screenX, tileNum<<1);
			screenX += 8;
		}
	}
}


